Flight Booking Flow Challenge

# ✈️ Flight Booking Flow Challenge

Complete the multi-step booking process from search to confirmation

1
Search
2
Select Flight
3
Passenger Details
4
Seat Selection
5
Payment
6
Confirmation

## Search Flights

From
To
Departure Date
Return Date
Passengers
Class

## Select Your Flight

## Passenger Details

## Select Your Seats

## Payment Information

💳
Credit Card
💰
Debit Card
📱
PayPal
Card Number
Expiry Date
CVV
Cardholder Name
✅
Booking Confirmed!

Your flight has been successfully booked. You will receive a confirmation email shortly.

Booking Reference: ABC123XYZ

### Booking Summary

Route: -
Date: -
Passengers: -
Flight: -
Seats: -
Total: -